@@ -33,8 +33,14 @@ bool dedupClasses(std::vector<double>& geneAlphas,
                   std::vector<TGroupT>& txpGroups,
                   std::vector<UGroupT>& umiGroups,
                   std::vector<SalmonEqClass>& salmonEqclasses,
+                  uint32_t umiLength,
                   spp::sparse_hash_map<uint32_t, uint32_t>& txpToGeneMap,
-                  std::vector<uint8_t>& tiers, 
-                  GZipWriter& gzw, bool dumpUmiGraph);
+                  std::vector<uint8_t>& tiers,
+                  GZipWriter& gzw, uint32_t umiEditDistance,
+                  bool dumpUmiGraph, std::string& trueBarcodeStr,
+                  std::vector<spp::sparse_hash_map<uint16_t, uint16_t>>& arboEqClassCount,
+                  bool dumpArborescences,
+                  std::atomic<uint64_t>& totalUniEdgesCounts,
+                  std::atomic<uint64_t>& totalBiEdgesCounts);
 
 #endif // DEDUP_UMI_HPP
