@@ -9,7 +9,7 @@
 #include "spdlog/spdlog.h"
 
 #include "AtomicMatrix.hpp"
-#include "tbb/concurrent_vector.h"
+#include "oneapi/tbb/concurrent_vector.h"
 
 class Transcript;
 class LibraryFormat;
